FROM ubuntu:24.04
LABEL maintainer="amass <168062547@qq.com>"
ENV DEBIAN_FRONTEND=noninteractive

ARG USER_NAME=amass
ARG USER_UID=1000
ARG USER_GID=100

ENV BOOST_VERSION=1_88_0
ENV CODE_VERSION=4.100.2
ENV LIBDATACHANNEL_VERSION=0.22.6
ENV NNG_VERSION=1.11
ENV MBEDTLS_VERSION=3.6.3.1
ENV TCPING_VERSION=2.7.1
ENV COTURN_VERSION=4.7.0

RUN sed -i 's@//.*archive.ubuntu.com@//mirrors.ustc.edu.cn@g' /etc/apt/sources.list.d/ubuntu.sources \
    && apt update \
    && apt install -y gcc g++ gdb cmake ninja-build pkg-config openssh-server git nano gpg ca-certificates \
        wget curl rsync lsb-release ubuntu-keyring gnupg2 libssl-dev zlib1g-dev gettext jq bzip2 unzip xz-utils \
        zsh htop tini sudo gosu \
    && echo 'if [ -f /etc/profile ]; then source /etc/profile; fi' >> /etc/zsh/zprofile \
    && install -m 0755 -d /etc/apt/keyrings \
    && curl -fsSL https://download.docker.com/linux/ubuntu/gpg -o /etc/apt/keyrings/docker.asc \
    && chmod a+r /etc/apt/keyrings/docker.asc \
    && echo "deb [arch=$(dpkg --print-architecture) signed-by=/etc/apt/keyrings/docker.asc] https://download.docker.com/linux/ubuntu $(. /etc/os-release && echo "$VERSION_CODENAME") stable" | tee /etc/apt/sources.list.d/docker.list > /dev/null \
    && wget -O - https://openresty.org/package/pubkey.gpg | gpg --dearmor -o /usr/share/keyrings/openresty.gpg \
    && echo "deb [arch=$(dpkg --print-architecture) signed-by=/usr/share/keyrings/openresty.gpg] http://openresty.org/package/ubuntu $(lsb_release -sc) main" | tee /etc/apt/sources.list.d/openresty.list > /dev/null \
    && apt update \
    && apt install -y docker-ce-cli openresty \
    && apt clean \
    && rm -fr /var/lib/apt/lists/* /tmp/* /var/tmp/*

RUN curl -fOL https://github.com/coder/code-server/releases/download/v$CODE_VERSION/code-server_${CODE_VERSION}_amd64.deb \
    && dpkg -i code-server_${CODE_VERSION}_amd64.deb \
    && rm code-server_${CODE_VERSION}_amd64.deb

RUN cd /opt \
    && git clone --depth=1 https://github.com/emscripten-core/emsdk.git \
    && cd /opt/emsdk \
    && ./emsdk install latest \
    && ./emsdk activate latest \
    && echo "export PATH=/opt/emsdk:/opt/emsdk/node/20.18.0_64bit/bin:/opt/emsdk/upstream/emscripten:$PATH" >> /etc/profile
ENV PATH=/opt/emsdk:/opt/emsdk/node/20.18.0_64bit/bin:/opt/emsdk/upstream/emscripten:$PATH

RUN cd /root \
    && BOOST_VERSION_DOT=$(echo $BOOST_VERSION | tr '_' '.') \
    && wget https://archives.boost.io/release/${BOOST_VERSION_DOT}/source/boost_${BOOST_VERSION}.tar.gz \
    && tar xvf boost_${BOOST_VERSION}.tar.gz > /dev/null \
    && cd /root/boost_${BOOST_VERSION} \
    && ./bootstrap.sh --prefix=/opt/Libraries/boost_${BOOST_VERSION} \
    && ./b2 install -q --prefix=/opt/Libraries/boost_${BOOST_VERSION} threading=multi link=static runtime-link=shared variant=release cxxstd=17 cxxflags=-fPIC cflags=-fPIC \
    && rm -fr /root/boost_${BOOST_VERSION}* \
    && echo "export LD_LIBRARY_PATH=/opt/Libraries/boost_${BOOST_VERSION}/lib:$LD_LIBRARY_PATH" >> /etc/profile
ENV LD_LIBRARY_PATH=/opt/Libraries/boost_${BOOST_VERSION}/lib:$LD_LIBRARY_PATH

RUN cd /root \
    && wget https://github.com/Mbed-TLS/mbedtls/releases/download/mbedtls-${MBEDTLS_VERSION}/mbedtls-${MBEDTLS_VERSION}.tar.bz2 \
    && tar xvf mbedtls-${MBEDTLS_VERSION}.tar.bz2 \
    && cd /root/mbedtls-${MBEDTLS_VERSION} \
    && cmake -G Ninja -B build -S . -DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX=/opt/Libraries/mbedtls-${MBEDTLS_VERSION} \
    && cmake --build build --target all \
    && cmake --install build \
    && rm -fr /root/mbedtls-${MBEDTLS_VERSION}*

RUN cd /root \
    && wget https://github.com/nanomsg/nng/archive/refs/tags/v${NNG_VERSION}.tar.gz -O nng-${NNG_VERSION}.tar.gz \
    && tar xvf nng-${NNG_VERSION}.tar.gz \
    && cd /root/nng-${NNG_VERSION} \
    && sed -i 's/# PATH_SUFFIXES lib/PATH_SUFFIXES lib/' cmake/FindMbedTLS.cmake \
    && sed -i '/_MBEDTLS_LIBRARY/{n;n;n;n;s/#PATH_SUFFIXES lib/PATH_SUFFIXES lib/}' cmake/FindMbedTLS.cmake \
    && cmake -G Ninja -B build -S . -DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX=/opt/Libraries/nng-${NNG_VERSION} -DNNG_ELIDE_DEPRECATED=ON -DNNG_ENABLE_TLS=ON -DMBEDTLS_ROOT=/opt/Libraries/mbedtls-${MBEDTLS_VERSION} -D_MBEDTLS_V2_OR_NEWER=ON \
    && cmake --build build --target all \
    && cmake --install build \
    && rm -fr /root/nng-${NNG_VERSION}*

RUN cd /root \
    && git clone --recursive --depth 1 -b v${LIBDATACHANNEL_VERSION} https://github.com/paullouisageneau/libdatachannel.git \
    && cd libdatachannel \
    && cmake -G Ninja -B build -S . -DUSE_GNUTLS=0 -DUSE_NICE=0 -DBUILD_SHARED_LIBS=OFF -DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX=/opt/Libraries/libdatachannel-${LIBDATACHANNEL_VERSION} \
    && cmake --build build --target all \
    && cmake --install build \
    && rm -fr /root/libdatachannel

RUN cd /root \
    && wget https://github.com/libjpeg-turbo/libjpeg-turbo/releases/download/3.1.0/libjpeg-turbo-3.1.0.tar.gz \
    && tar xvf libjpeg-turbo-3.1.0.tar.gz \
    && cd /root/libjpeg-turbo-3.1.0 \
    && cmake -G Ninja -B build -S . -DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX=/opt/Libraries/libjpeg-turbo-3.1.0 -DENABLE_SHARED=OFF \
    && cmake --build build --target all \
    && cmake --install build \
    && rm -fr /root/libjpeg-turbo-3.1.0*

RUN wget https://github.com/pouriyajamshidi/tcping/releases/download/v${TCPING_VERSION}/tcping-linux-amd64-static.tar.gz -O /tmp/tcping-linux-amd64-static.tar.gz \
    && tar -xzf /tmp/tcping-linux-amd64-static.tar.gz -C /usr/bin \
    && rm /tmp/tcping-linux-amd64-static.tar.gz

RUN cd /root \
    && wget https://github.com/libevent/libevent/releases/download/release-2.1.12-stable/libevent-2.1.12-stable.tar.gz \
    && tar -xvf libevent-2.1.12-stable.tar.gz \
    && cd libevent-2.1.12-stable \
    && cmake -G Ninja -B build -S . -DCMAKE_INSTALL_PREFIX=/opt/Libraries/libevent-2.1.12 -DEVENT__LIBRARY_TYPE=STATIC \
    && cmake --build build --target all \
    && cmake --install build \
    && rm -fr /root/libevent-2.1.12*

RUN cd /root \
    && wget https://github.com/coturn/coturn/archive/refs/tags/${COTURN_VERSION}.tar.gz -O coturn-${COTURN_VERSION}.tar.gz \
    && tar xvf coturn-${COTURN_VERSION}.tar.gz \
    && cd coturn-${COTURN_VERSION} \
    && cmake -G Ninja -B build -S . -DCMAKE_INSTALL_PREFIX=/opt/Libraries/coturn-${COTURN_VERSION} -DLibevent_DIR=/opt/Libraries/libevent-2.1.12/lib/cmake/libevent \
    && cmake --build build --target all \
    && cmake --install build \
    && rm -fr /root/coturn-${COTURN_VERSION}*

RUN cd /root \
    && git clone --depth=1 --recursive https://github.com/ZLMediaKit/ZLMediaKit.git \
    && cd /root/ZLMediaKit \
    && apt update \
    && apt install -y libsrtp2-dev libusrsctp-dev \
    && apt clean \
    && rm -fr /var/lib/apt/lists/* /tmp/* /var/tmp/* \
    && cmake -G Ninja -B build -S . -DENABLE_OPENSSL=true -DENABLE_WEBRTC=true -DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX="/opt/Libraries/ZLMediaKit" \
    && cmake --build build --target all \
    && cmake --install build \
    && rm -fr /root/ZLMediaKit \
    && echo 'export PATH=/opt/Libraries/ZLMediaKit/bin:$PATH' >> /etc/profile \
    && echo 'export LD_LIBRARY_PATH=/opt/Libraries/ZLMediaKit/lib:$LD_LIBRARY_PATH' >> /etc/profile
ENV LD_LIBRARY_PATH=/opt/Libraries/ZLMediaKit/lib:$LD_LIBRARY_PATH
ENV PATH=/opt/Libraries/ZLMediaKit/bin:$PATH

ENV LANG=C.UTF-8
ENV LC_ALL=C.UTF-8
ENV TERM=xterm-256color

RUN mkdir /var/run/sshd \
    && sed -i 's/#Port 22/Port 1022/' /etc/ssh/sshd_config  \
    && sed -i 's/#PubkeyAuthentication yes/PubkeyAuthentication yes/' /etc/ssh/sshd_config
EXPOSE 1022

RUN set -eux; \
    if getent passwd ${USER_UID} >/dev/null; then \
        OLD_USER=$(getent passwd ${USER_UID} | cut -d: -f1); \
        userdel -rf "$OLD_USER" || true; \
    fi; \
    if ! getent group ${USER_GID} >/dev/null; then \
        groupadd -g ${USER_GID} users; \
    fi; \
    useradd -u ${USER_UID} -g ${USER_GID} -m -s /bin/zsh ${USER_NAME}; \
    usermod -aG sudo ${USER_NAME}; \
    echo "${USER_NAME} ALL=(ALL) NOPASSWD: ALL" >> /etc/sudoers

RUN mkdir -p /home/${USER_NAME}/.ssh \
    && chown ${USER_UID}:${USER_GID} /home/${USER_NAME}/.ssh \
    && chmod 700 /home/${USER_NAME}/.ssh \
    && wget https://cloud.amass.fun/s/Z42BPTsfjB53k35/download -O /home/${USER_NAME}/.ssh/authorized_keys \
    && chown ${USER_UID}:${USER_GID} /home/${USER_NAME}/.ssh/authorized_keys \
    && chmod 600 /home/${USER_NAME}/.ssh/authorized_keys

USER ${USER_NAME}

RUN git config --global core.quotepath false \
	&& git config --global user.email "168062547@qq.com" \
	&& git config --global user.name ${USER_NAME}

RUN sh -c "$(curl -fsSL https://raw.githubusercontent.com/ohmyzsh/ohmyzsh/master/tools/install.sh)" \
    && git clone --depth=1 https://github.com/zsh-users/zsh-autosuggestions ${ZSH_CUSTOM:-~/.oh-my-zsh/custom}/plugins/zsh-autosuggestions \
    && git clone --depth=1 https://github.com/zsh-users/zsh-syntax-highlighting.git ${ZSH_CUSTOM:-~/.oh-my-zsh/custom}/plugins/zsh-syntax-highlighting \
    && git clone --depth=1 https://github.com/romkatv/powerlevel10k.git ${ZSH_CUSTOM:-$HOME/.oh-my-zsh/custom}/themes/powerlevel10k \
    && sed -i 's/ZSH_THEME=".*"/ZSH_THEME="powerlevel10k\/powerlevel10k"/' ~/.zshrc \
    && sed -i 's/plugins=(.*)/plugins=(git z zsh-autosuggestions zsh-syntax-highlighting)/' ~/.zshrc \
    && sed -i 's/^setopt share_history/# setopt share_history/' ~/.oh-my-zsh/lib/history.zsh \
    && echo 'setopt no_share_history' >> ~/.oh-my-zsh/lib/history.zsh
    
USER root
ENTRYPOINT ["/usr/bin/tini", "--"]
CMD ["bash", "-c", "service ssh start && gosu amass code-server --bind-addr 0.0.0.0:8087"]
# CMD ["bash", "-c", "service ssh start && tail -f /dev/null"]
# docker build --no-cache --progress=tty -f ubuntu2404.dockerfile -t registry.cn-shenzhen.aliyuncs.com/amass_toolset/ubuntu_dev:24.04 .
# docker push registry.cn-shenzhen.aliyuncs.com/amass_toolset/ubuntu_dev:24.04